@@ -15,6 +15,11 @@ impl Correction {
 		&self.corr.coef
 	}
 
+	/// Returns coefficient values for editing
+	pub fn coefficient_mut(&mut self) -> &mut [i32; 8] {
+		&mut self.corr.coef
+	}
+
 	pub const fn new(coefficient: &[i32; 8], precision: i16, type_: CorrectionType) -> Self {
 		Self {
 			corr: js_corr {
@@ -29,6 +34,16 @@ impl Correction {
 		self.corr.prec
 	}
 
+	/// Set precision
+	pub fn set_precision(&mut self, precision: i16) {
+		self.corr.prec = precision;
+	}
+
+	/// Set type
+	pub fn set_type(&mut self, type_: CorrectionType) {
+		self.corr.prec = type_ as i16;
+	}
+
 	pub fn type_(&self) -> CorrectionType {
 		unsafe { transmute(self.corr.type_) }
 	}
